@@ -1,10 +1,12 @@
 package Encode::JP::Mobile::Vodafone;
 use strict;
 use base qw(Encode::Encoding);
-__PACKAGE__->Define(qw(shift_jis-vodafone));
+__PACKAGE__->Define(qw(x-sjis-vodafone));
 
 use Encode::Alias;
-define_alias('shift_jis-softbank' => 'shift_jis-vodafone');
+define_alias('x-sjis-softbank' => 'x-sjis-vodafone');
+define_alias('shift_jis-softbank' => 'x-sjis-softbank');
+define_alias('shift_jis-vodafone' => 'x-sjis-vodafone');
 
 # G! => E001, G" => E002, G# => E003 ...
 # E! => E101, F! => E201, O! => E301, P! => E401, Q! => E501
